RowData class

Constructors

RowData({String? key, dynamic value, bool? isExpanded, List<JsonKeyType>? jsonKeyTypes, int? collapseCount, int level = 0, int index = 0, int? arrayIndex, int? childrenCount, bool isParent = false})

Properties

arrayIndex ↔ int?
getter/setter pair
childrenCount ↔ int?
getter/setter pair
collapseCount ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
isExpanded ↔ bool
getter/setter pair
isParent ↔ bool
getter/setter pair
jsonKeyTypes ↔ List<JsonKeyType>?
getter/setter pair
key ↔ String?
getter/setter pair
level ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
getter/setter pair

Methods

getEndTypes() → List<JsonKeyType>
hasEndType() → bool
hasNotLastEndType() → bool
hasStartType() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited