TextUtils class

Constructors

TextUtils({TextStyle? defaultStyle})

Properties

avgMaxKeyLength ↔ int
getter/setter pair
avgMaxValueLength ↔ int
getter/setter pair
cachedCharWidth ↔ Map<String, double>
getter/setter pair
cacheMain ↔ Map<dynamic, double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxKeyWidth ↔ double
getter/setter pair
maxValueWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textPainter ↔ TextPainter
getter/setter pair

Methods

calcAvgMaxLength(double maxKeyWidth, double maxValueWidth, {double ratio = 0.9}) → dynamic
checkNeedMaxWidth(String? text) → bool
getFittedWidth(String? key, dynamic value, {double? maxKeyWidth, double? maxValueWidth}) → double
getMaxWidth(Characters? text, int avgLength, double? maxWidth) → double
messureText(Characters? text, {double? width, TextStyle? style}) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMaxWidth(double maxKeyWidth, double maxValueWidth) → dynamic
setStyle(TextStyle style) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited